@@ -205,7 +205,7 @@ class DataAccess:
             print('Failed to fetch user Information')
             print(e)
 
-    def get_dp(self, device_id, sensors=['D29'], n=1, cal=True, end_time=datetime.now()):
+    def get_dp(self, device_id, sensors=['D29'], n=1, cal=True, end_time=datetime.now(),IST=True):
         """
 
         :param device_id: string
@@ -256,18 +256,26 @@ class DataAccess:
                     counter = counter + 1
                 if cursor['end'] == None:
                     break
-            if cal == True or cal == 'true' or cal == "TRUE":
-                df,metadata = DataAccess.get_sensor_alias(self, device_id, df_raw,metadata)
-                df = DataAccess.get_cleaned_table(self, df)
-                df = DataAccess.get_caliberation(self, device_id, metadata,df)
+            if len(df_raw) != 0:
+                if IST:
+                    df_raw['time'] = pd.to_datetime(df_raw['time'], utc=False)
+                    df_raw['time'] = df_raw['time'].dt.tz_convert('Asia/Kolkata')
+                    df_raw['time'] = df_raw['time'].dt.tz_localize(None)
+                if cal == True or cal == 'true' or cal == "TRUE":
+                    df,metadata = DataAccess.get_sensor_alias(self, device_id, df_raw,metadata)
+                    df = DataAccess.get_cleaned_table(self, df)
+                    df = DataAccess.get_caliberation(self, device_id, metadata,df)
+                else:
+                    df,metadata = DataAccess.get_sensor_alias(self, device_id,df_raw,metadata)
+                    df = DataAccess.get_cleaned_table(self, df)
             else:
-                df,metadata = DataAccess.get_sensor_alias(self, device_id,df_raw,metadata)
-                df = DataAccess.get_cleaned_table(self, df)
-            return df
+                df = df_raw
+                return df
+
         except Exception as e:
             print(e)
 
-    def data_query(self, device_id, start_time, end_time=datetime.now(), sensors=None, cal=True, bands=None, echo=True):
+    def data_query(self, device_id, start_time, end_time=datetime.now(), sensors=None, cal=True, bands=None, IST=True ,echo=True):
         # df = pd.DataFrame()
         metadata = {}
         if sensors == None:
@@ -331,23 +339,28 @@ class DataAccess:
                 break
         # print(rawdata_res)
         df_raw = pd.DataFrame(rawdata_res)
-        df_raw['time'] = pd.to_datetime(df_raw['time'], utc=False)
-        df_raw['time'] = df_raw['time'].dt.tz_convert('Asia/Kolkata')
-        df_raw['time'] = df_raw['time'].dt.tz_localize(None)
-        if len(df_raw.columns) == 2:
-            df_raw['sensor'] = sensors[0]
 
-        # print(df_raw)
-        if cal or cal == 'true' or cal == "TRUE":
-            # #qq=qq[~qq['value'].isin(['','BAD 255','BAD 0','BAD undefined','-'])]
-            df,metadata = DataAccess.get_sensor_alias(self, device_id, df_raw,metadata)
-            df = DataAccess.get_cleaned_table(self, df)
-            df = DataAccess.get_caliberation(self, device_id, metadata, df)
+        if len(df_raw) != 0 :
+            if IST:
+                df_raw['time'] = pd.to_datetime(df_raw['time'], utc=False)
+                df_raw['time'] = df_raw['time'].dt.tz_convert('Asia/Kolkata')
+                df_raw['time'] = df_raw['time'].dt.tz_localize(None)
+            if len(df_raw.columns) == 2:
+                df_raw['sensor'] = sensors[0]
+
+            # print(df_raw)
+            if cal or cal == 'true' or cal == "TRUE":
+                # #qq=qq[~qq['value'].isin(['','BAD 255','BAD 0','BAD undefined','-'])]
+                df,metadata = DataAccess.get_sensor_alias(self, device_id, df_raw,metadata)
+                df = DataAccess.get_cleaned_table(self, df)
+                df = DataAccess.get_caliberation(self, device_id, metadata, df)
+            else:
+                df,metadata = DataAccess.get_sensor_alias(self, device_id, df_raw,metadata)
+                df = DataAccess.get_cleaned_table(self, df)
+            if bands is not None:
+                df = DataAccess.time_grouping(self, df, bands)
         else:
-            df,metadata = DataAccess.get_sensor_alias(self, device_id, df_raw,metadata)
-            df = DataAccess.get_cleaned_table(self, df)
-        if bands is not None:
-            df = DataAccess.time_grouping(self, df, bands)
+            df = df_raw
         return df
 
     def publish_event(self, title, message, meta_data, hover_data, event_tags, created_on):
